@@ -15,20 +15,23 @@
 
 #include "image-source.h"
 
-// Various implementations we try in the constructor
-#include <errno.h>
 #include <fcntl.h>
-#include <math.h>
-#include <string.h>
+#include <netinet/in.h>
 #include <strings.h>
 #include <sys/stat.h>
-#include <sys/types.h>
 #include <unistd.h>
 
+#include <cerrno>
+#include <cmath>
+#include <cstdint>
+#include <cstring>
 #include <memory>
 #include <sstream>
+#include <string>
 #include <utility>
 
+// Various implementations for the factory.
+#include "display-options.h"
 #include "graphics-magick-source.h"
 #include "jpeg-source.h"
 #include "openslide-source.h"
@@ -293,16 +296,23 @@ std::string ImageSource::FormatFromParameters(const std::string &fmt_string,
 }
 
 static bool HasAPNGHeader(const std::string &filename) {
-    // Somewhat handwavy: the "acTL" chunk could of course be at other places as
-    // well, let's assume it is just after IHDR.
+    static constexpr size_t kPngHeaderLen = 8;
+
+    // Iterate through headers in the first kibibyte until we find an acTL one.
     int fd = open(filename.c_str(), O_RDONLY);
     if (fd < 0) return false;
-    char actl_sig[4]                   = {};
-    static constexpr int kPngHeaderLen = 8;
-    static constexpr int kPngIHDRLen   = 8 + 13 + 4;
-    const ssize_t len = pread(fd, actl_sig, 4, kPngHeaderLen + kPngIHDRLen + 4);
+    size_t pos = kPngHeaderLen;
+    uint8_t buf[8];
+    bool found_actl_header = false;
+    while (!found_actl_header && pos < 1024) {
+        const ssize_t len = pread(fd, buf, 8, pos);
+        if (len < 0 || len != 8) break;  // Best effort.
+        found_actl_header = (memcmp(buf + 4, "acTL", 4) == 0);
+        // Header contains data length; add sizeof() for len, CRC, and ChunkType
+        pos += ntohl(*(uint32_t *)buf) + 12;
+    }
     close(fd);
-    return len == 4 && memcmp(actl_sig, "acTL", 4) == 0;
+    return found_actl_header;
 }
 
 bool ImageSource::LooksLikeAPNG(const std::string &filename) {
